==> cdate-0.0.1.tgz: package/src/cdate.js <==
import { formatPlugin } from "./format/texter.js";
import { calcPlugin } from "./calc/calc.js";
import { utcPlugin } from "./timezone/dateutc.js";
import { tzPlugin } from "./timezone/timezone.js";
import { localePlugin } from "./locale/locale.js";
class CDateCore {
    /**
     * the constructor
     */
    constructor(t, x) {
        this.t = t;
        if ("number" !== typeof t) {
            this.d = t;
        }
        this.x = x || {};
    }
    /**
     * creates another CDate object
     */
    cdate(dt) {
        if (dt == null) {
            dt = new Date(); // now
        }
        else if ("string" === typeof dt) {
            dt = new Date(dt); // parse ISO string
        }
        else {
            dt = new Date(+dt); // number or DateLike
        }
        return this.create(dt);
    }
    /**
     * returns a read-write version of DateLike for manipulation
     */
    rw() {
        const t = +this.t;
        const rw = this.x.rw;
        return rw ? rw(t) : new Date(t);
    }
    /**
     * returns a read-only version of DateLike for displaying
     */
    ro() {
        return this.d || (this.d = this.rw());
    }
    /**
     * returns milliseconds since the epoch
     */
    valueOf() {
        return +this.ro();
    }
    /**
     * returns a raw Date object
     */
    toDate() {
        return new Date(+this);
    }
    /**
     * returns a JSON string
     */
    toJSON() {
        return this.toDate().toJSON();
    }
    plugin(fn) {
        const CDateClass = this.constructor;
        const CDateX = fn(CDateClass) || CDateClass;
        return new CDateX(this.t, this.x);
    }
    /**
     * creates another CDate object with the DateLike given
     */
    create(dt) {
        return new this.constructor(dt, this.x);
    }
    /**
     * clones the CDate object
     */
    inherit() {
        const out = this.create(+this);
        // x is readonly
        out.x = Object.create(out.x);
        return out;
    }
}
const root = new CDateCore(0, {})
    .plugin(formatPlugin)
    .plugin(calcPlugin)
    .plugin(localePlugin)
    .plugin(utcPlugin)
    .plugin(tzPlugin);
export const cdate = (dt) => root.cdate(dt);

==> cdate-0.0.2.tgz: package/src/cdate.js <==
import { formatPlugin } from "./format/texter.js";
import { calcPlugin } from "./calc/calc.js";
import { tzPlugin } from "./timezone/timezone.js";
class CDateCore {
    /**
     * the constructor
     */
    constructor(t, x) {
        this.t = t;
        if ("number" !== typeof t) {
            this.d = t;
        }
        this.x = x || Object.create({ cdate: {} });
    }
    /**
     * cdate function factory
     */
    cdateFn() {
        return cdateFn(this);
    }
    /**
     * returns a read-write version of DateLike for manipulation
     */
    rw() {
        const t = +this.t;
        const rw = this.x.rw;
        return rw ? rw(t) : new Date(t);
    }
    /**
     * returns a read-only version of DateLike for displaying
     */
    ro() {
        return this.d || (this.d = this.rw());
    }
    /**
     * returns milliseconds since the epoch
     */
    valueOf() {
        return +this.ro();
    }
    /**
     * returns a bare Date object
     */
    toDate() {
        return new Date(+this);
    }
    /**
     * returns a JSON representation of Date
     */
    toJSON() {
        return this.toDate().toJSON();
    }
    /**
     * returns an instance including the plugin
     */
    plugin(fn) {
        const CDateClass = this.constructor;
        const CDateX = fn(CDateClass) || CDateClass;
        return new CDateX(this.t, this.x);
    }
    /**
     * creates another CDate object with the DateLike given
     */
    create(dt) {
        return new this.constructor(dt, this.x);
    }
    /**
     * clones the CDate object
     */
    inherit() {
        const out = this.create(+this);
        // x is readonly
        out.x = Object.create(out.x);
        return out;
    }
}
const cdateFn = (base) => {
    return (dt) => {
        if (dt == null) {
            dt = new Date(); // now
        }
        else if ("string" === typeof dt) {
            // YYYY-MM-DD as is
            // YYYY-MM for YYYY-MM-01
            // YYYY for YYYY-01-01
            const m = dt.match(/^(\d{4})(?:([-/])(0[1-9]|1[0-2])(?:\2(0[1-9]|12[0-9]|3[01]))?)?$/);
            if (m) {
                const year = +m[1];
                const month = +m[3] || 1;
                const date = +m[4] || 1;
                dt = new Date(year, (month - 1), date);
                if (year < 100)
                    dt.setFullYear(year);
            }
            else {
                dt = new Date(dt); // parse ISO string natively
            }
        }
        else {
            dt = new Date(+dt); // number or DateLike
        }
        return base.create(dt);
    };
};
export const cdate = new CDateCore(0, null)
    .plugin(formatPlugin)
    .plugin(calcPlugin)
    .plugin(tzPlugin)
    .cdateFn();
